<template>
    <div class="app-container">
        <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">

            <el-form-item label="编码" prop="harmCode">
                <el-input v-model="queryParams.harmCode" placeholder="请输入编码" clearable @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="名称" prop="harmType">
                <el-input v-model="queryParams.harmType" placeholder="请输入职业病拼音码" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="拼音码" prop="harmPinYin">
                <el-input v-model="queryParams.harmPinYin" placeholder="请输入职业病拼音码" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>

            <el-form-item>
                <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
                <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
                    v-hasPermi="['hosp:harmType:add']">新增
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
                    v-hasPermi="['hosp:harmType:edit']">修改
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
                    v-hasPermi="['hosp:harmType:remove']">删除
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
                    v-hasPermi="['hosp:harmType:export']">导出
                </el-button>
            </el-col>
            <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>

        <el-table v-loading="loading" :data="harmTypeList" @selection-change="handleSelectionChange" border>
            <el-table-column type="selection" width="55" align="center" />
            <el-table-column label="排序" align="center" prop="sort" />
            <el-table-column label="职业病编码" align="center" prop="harmCode" />
            <el-table-column label="职业病名称" align="center" prop="harmType" />
            <el-table-column label="职业病拼音码" align="center" prop="harmPinYin" />
            <el-table-column label="信息" align="center" prop="harmInfo" />
            <el-table-column label="防护措施" align="center" prop="protection" />
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
                <template slot-scope="scope">
                    <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
                        v-hasPermi="['hosp:harmType:edit']">修改
                    </el-button>
                    <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
                        v-hasPermi="['hosp:harmType:remove']">删除
                    </el-button>
                </template>
            </el-table-column>
        </el-table>

        <div class="pag">
            <div class="pag1">
                <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum"
                    :limit.sync="queryParams.pageSize" @pagination="getList" />
            </div>
        </div>


        <!-- 添加或修改职业病对话框 -->
        <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
            <el-form ref="form" :model="form" :rules="rules" label-width="80px">
                <el-form-item label="排序" prop="sort">
                    <el-input v-model="form.sort" placeholder="请输入排序" />
                </el-form-item>
                <el-form-item label="编码" prop="harmCode">
                    <el-input v-model="form.harmCode" placeholder="请输入编码" />
                </el-form-item>
                <el-form-item label="拼音码" prop="harmPinYin">
                    <el-input v-model="form.harmPinYin" placeholder="请输入拼音码" />
                </el-form-item>
                <el-form-item label="名称" prop="harmType">
                    <el-input v-model="form.harmType" placeholder="请输入拼音码" />
                </el-form-item>

                <el-form-item label="信息" prop="harmInfo">
                    <el-input v-model="form.harmInfo" type="textarea" placeholder="请输入内容" />
                </el-form-item>


                <el-form-item label="防护措施" prop="protection">
                    <el-input v-model="form.protection" placeholder="请输入防护措施" />
                </el-form-item>
            </el-form>
            <div slot="footer" class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import {
    listHarmType,
    getHarmType,
    delHarmType,
    addHarmType,
    updateHarmType
} from "@/api/hosp/harmType";

export default {
    name: "HarmType",
    data() {
        let checkPhoneNum = (rule, value, callback) => {
            console.log(value)
            let patter = new RegExp(/^1\s*[3456789]\s*(\d\s*){9}$/);
            if (value == "" && value == undefined && !value) {
                return callback('');
            } else if (value != undefined && value != "") {
                return callback();
            } else if (!patter.test(value)) {
                return callback('');
            }
        };
        return {
            // 遮罩层
            loading: true,
            // 选中数组
            ids: [],
            // 非单个禁用
            single: true,
            // 非多个禁用
            multiple: true,
            // 显示搜索条件
            showSearch: true,
            // 总条数
            total: 0,
            // 职业病表格数据
            harmTypeList: [],
            // 弹出层标题
            title: "",
            // 是否显示弹出层
            open: false,
            // 查询参数
            queryParams: {
                pageNum: 1,
                pageSize: 10,
                harmpinyin: null,
                harmtype: null,
                sort: null,
                harminfo: null,
                externalcode: null,
                harmcode: null,
                type: null,
                protection: null
            },
            // 表单参数
            form: {},
            // 表单校验
            rules: {
                sort: [
                    { required: true, validator: checkPhoneNum, trigger: "blur" }
                ],
                harmCode: [
                    { required: true, validator: checkPhoneNum, trigger: "blur" }
                ],
                
                harmPinYin: [
                    { required: true, validator: checkPhoneNum, trigger: "blur" }
                ],
                
                harmType: [
                    { required: true, validator: checkPhoneNum, trigger: "blur" }
                ],
                
                harmInfo: [
                    { required: true, validator: checkPhoneNum, trigger: "blur" }
                ],
                
                protection: [
                    { required: true, validator: checkPhoneNum, trigger: "blur" }
                ],
                

            
            }
        };
    },
    created() {
        this.getList();
    },
    methods: {
        /** 查询职业病列表 */
        getList() {
            this.loading = true;
            listHarmType(this.queryParams).then(response => {
                this.harmTypeList = response.rows;
                this.total = response.total;
                this.loading = false;
            });
        },
        // 取消按钮
        cancel() {
            this.open = false;
            this.reset();
        },
        // 表单重置
        reset() {
            this.form = {
                aid: null,
                harmpinyin: null,
                harmtype: null,
                sort: null,
                harminfo: null,
                externalcode: null,
                harmcode: null,
                type: null,
                protection: null
            };
            this.resetForm("form");
        },
        /** 搜索按钮操作 */
        handleQuery() {
            this.queryParams.pageNum = 1;
            this.getList();
        },
        /** 重置按钮操作 */
        resetQuery() {
            this.resetForm("queryForm");
            this.handleQuery();
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            this.ids = []
            this.ids = selection.map(item => item.aid)
            this.single = selection.length !== 1
            this.multiple = !selection.length
        },
        /** 新增按钮操作 */
        handleAdd() {
            this.reset();
            this.open = true;
            this.title = "添加职业病";
        },
        /** 修改按钮操作 */
        handleUpdate(row) {
            this.reset();
            const aid = row.aid || this.ids
            getHarmType(aid).then(response => {
                this.form = response.data;
                this.open = true;
                this.title = "修改职业病";
            });
        },
        /** 提交按钮 */
        submitForm() {
            this.$refs["form"].validate((valid) => {
                if (valid) {
                    if (this.form.aid != null) {
                        updateHarmType(this.form).then((response) => {
                            this.$modal.msgSuccess("修改成功");
                            this.open = false;
                            this.getList();
                        });
                    } else {
                        addHarmType(this.form).then((response) => {
                            this.$modal.msgSuccess("新增成功");
                            this.open = false;
                            this.getList();
                        });
                    }
                }
            });
        },
        /** 删除按钮操作 */
        handleDelete(row) {
            if (row) {
                this.ids = []
                this.ids.push(row.aid)
            }

            const ids = this.ids;
            this.$modal
                .confirm('是否确认删除advice编号为"' + ids + '"的数据项？')
                .then(function () {
                    return delHarmType(ids);
                })
                .then(() => {
                    this.getList();
                    this.$modal.msgSuccess("删除成功");
                })
                .catch(() => { });
        },


        SelectionChange(selection) { },



        /** 导出按钮操作 */
        handleExport() {

        }
    }
}
    ;
</script>


<style>
.pag {
    width: 100%;
    display: flex;
    justify-content: center;
}

.pag1 {
    width: 30%;
}
</style>
